# -*- coding: utf-8 -*-
"""Test Layer for pspolicy.homes4.base."""

# zope imports
from plone.app.testing import (
    IntegrationTesting,
    PloneSandboxLayer,
    PLONE_FIXTURE,
    applyProfile,
)
from zope.configuration import xmlconfig


class PSPolicyHomes4Base(PloneSandboxLayer):
    """Custom Test Layer for pspolicy.homes4.base."""
    defaultBases = (PLONE_FIXTURE, )

    def setUpZope(self, app, configurationContext):
        """Set up Zope for testing."""
        # Load ZCML
        import pspolicy.homes4.base
        xmlconfig.file(
            'configure.zcml', pspolicy.homes4.base,
            context=configurationContext,
        )

    def setUpPloneSite(self, portal):
        """Set up a Plone site for testing."""
        applyProfile(portal, 'pspolicy.homes4.base:default')


PSPOLICY_HOMES4_BASE_FIXTURE = PSPolicyHomes4Base()
PSPOLICY_HOMES4_BASE_INTEGRATION_TESTING = IntegrationTesting(
    bases=(PSPOLICY_HOMES4_BASE_FIXTURE, ),
    name='PSPolicyHomes4Base:Integration',
)



# -*- coding: utf-8 -*-
"""Test settings applied by pspolicy.homes4.base."""

# python imports
import unittest2 as unittest

# zope imports
from Products.CMFCore.utils import getToolByName
from collective.cover.controlpanel import ICoverSettings
from plone.app.caching.interfaces import IPloneCacheSettings
from plone.cachepurging.interfaces import ICachePurgingSettings
from plone.caching.interfaces import ICacheSettings
from plone.registry.interfaces import IRegistry
from theming.toolkit.core.interfaces import IToolkitSettings
from zope.component import getUtility

# local imports
from pspolicy.homes4.base.testing import (
    PSPOLICY_HOMES4_BASE_INTEGRATION_TESTING,
)


class TestSettings(unittest.TestCase):
    """Settings Test Case for pspolicy.homes4.base."""
    layer = PSPOLICY_HOMES4_BASE_INTEGRATION_TESTING

    def setUp(self):
        """Additional test setup."""
        self.portal = self.layer['portal']
        self.p_properties = getToolByName(self.portal, 'portal_properties')
        self.portal_workflow = getToolByName(self.portal, 'portal_workflow')
        self.registry = getUtility(IRegistry)

    def test_cache_settings(self):
        """Validate the plone.app.caching settings."""
        settings = self.registry.forInterface(ICacheSettings)
        self.assertTrue(settings.enabled)

    def test_cover_settings(self):
        """Validate the collective.cover settings."""
        settings = self.registry.forInterface(ICoverSettings)
        available_tiles = settings.available_tiles
        self.assertIn('collective.cover.pfg', available_tiles)
        self.assertNotIn('collective.cover.carousel', available_tiles)

    def test_dc_metadata_exposed(self):
        """Validate the DC Core metadata option is enabled."""
        sp = self.p_properties.get('site_properties')
        self.failUnless(sp)
        self.assertTrue(getattr(sp, "exposeDCMetaTags"))

    def test_mailhost_host(self):
        """Validate the SMTP Server settings."""
        mailhost = getToolByName(self.portal, 'MailHost')
        self.assertEquals('localhost', mailhost.smtp_host)
        self.assertEquals(25, mailhost.smtp_port)

    def test_plone_cache_settings(self):
        """Validate the plone.app.caching settings."""
        settings = self.registry.forInterface(IPloneCacheSettings)
        self.assertTrue(settings.enableCompression)
        mapping = settings.templateRulesetMapping
        self.assertIn('leadImage', mapping.keys())
        self.assertIn('leadImage_preview', mapping.keys())
        self.assertIn('leadImage_thumb', mapping.keys())
        self.assertEquals('plone.content.file', mapping.get('leadImage'))
        self.assertEquals(
            'plone.content.file',
            mapping.get('leadImage_preview'),
        )
        self.assertEquals(
            'plone.content.file',
            mapping.get('leadImage_thumb'),
        )

    def test_plone_cache_purge_settings(self):
        """Validate the plone.cachepurging settings."""
        settings = self.registry.forInterface(ICachePurgingSettings)
        self.assertTrue(settings.enabled)
        self.assertTrue(settings.virtualHosting)
        self.assertEquals(('http://localhost:9000',), settings.cachingProxies)

    def test_site_title(self):
        """Validate the site title."""
        self.assertEquals("Homes4", self.portal.getProperty("title"))

    def test_sitemap_enabled(self):
        """Validate that sitemap.xml.gz option is enabled."""
        sp = self.p_properties.get('site_properties')
        self.failUnless(sp)
        self.assertTrue(getattr(sp, "enable_sitemap"))

    def test_social_like_settings(self):
        """Validate sc.social.like settings."""
        sp = self.p_properties.get('sc_social_likes_properties')
        self.failUnless(sp)
        self.assertEquals('propertyshelf', getattr(sp, 'twittvia'))

        plugins = getattr(sp, 'plugins_enabled', [])
        self.assertIn('Facebook', plugins)
        self.assertIn('Google+', plugins)
        self.assertIn('LinkedIn', plugins)
        self.assertIn('Pinterest', plugins)
        self.assertIn('Twitter', plugins)

        p_types = getattr(sp, 'enabled_portal_types', [])
        self.assertIn('Event', p_types)
        self.assertIn('File', p_types)
        self.assertIn('Folder', p_types)
        self.assertIn('FormFolder', p_types)
        self.assertIn('Image', p_types)
        self.assertIn('Link', p_types)
        self.assertIn('plone.mls.listing.listing', p_types)
        self.assertIn('News Item', p_types)
        self.assertIn('Document', p_types)

    def test_theming_toolkit_core_settings(self):
        """Validate the theming.toolkit.core settings."""
        settings = self.registry.forInterface(IToolkitSettings)
        self.assertFalse(settings.show_featuredNavigation)
        self.assertFalse(settings.show_headerplugin)

    def test_tinymce_settings(self):
        """Validate TinyMCE editor settings."""
        utility = getToolByName(self.portal, 'portal_tinymce')
        self.assertTrue(utility.link_using_uids)
        self.assertTrue(utility.toolbar_visualchars)
        self.assertTrue(utility.toolbar_media)
        self.assertTrue(utility.toolbar_removeformat)
        self.assertTrue(utility.toolbar_pasteword)
        self.assertTrue(utility.toolbar_pastetext)
        self.assertTrue(utility.toolbar_visualaid)
        self.assertTrue(utility.toolbar_cleanup)



# -*- coding: utf-8 -*-
"""Setup for pspolicy.homes4.base package."""

from setuptools import setup, find_packages

version = '0.2'

long_description = (
    open('README.rst').read()
    + '\n' +
    open('CONTRIBUTORS.rst').read()
    + '\n' +
    open('CHANGES.rst').read()
    + '\n')


install_requires = [
    'setuptools',
    'Products.Carousel',
    'Products.Doormat',
    'Products.PloneFormGen',
    'Products.RedirectionTool',
    'collective.carousel',
    'collective.contentleadimage',
    'collective.cover',
    'collective.googleanalytics',
    'collective.quickupload',
    'plone.app.caching',
    'plone.app.theming',
    'plone.mls.listing',
    'sc.social.like',
    'theming.toolkit.core',
    'theming.toolkit.viewlets',
    'theming.toolkit.views',
    'z3c.unconfigure',
]


setup(
    name='pspolicy.homes4.base',
    version=version,
    description="Plone Policy Add-On for the Homes4 sites.",
    long_description=long_description,
    # Get more strings from
    # http://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Environment :: Web Environment",
        "Operating System :: OS Independent",
        "Framework :: Zope2",
        "Framework :: Plone",
        "Framework :: Plone :: 4.2",
        "Framework :: Plone :: 4.3",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    keywords='plone policy',
    author='Propertyshelf, Inc.',
    author_email='development@propertyshelf.com',
    url='https://github.com/propertyshelf/pspolicy.homes4.base',
    license='gpl',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    namespace_packages=['pspolicy', 'pspolicy.homes4'],
    include_package_data=True,
    zip_safe=False,
    install_requires=install_requires,
    extras_require={
        'test': [
            'plone.app.testing',
        ],
    },
    entry_points="""
    # -*- Entry points: -*-
    [z3c.autoinclude.plugin]
    target = plone
    """
)



# -*- coding: utf-8 -*-
"""Test Setup of pspolicy.homes4.base."""

# python imports
import unittest2 as unittest

# local imports
from pspolicy.homes4.base.testing import (
    PSPOLICY_HOMES4_BASE_INTEGRATION_TESTING,
)


class TestSetup(unittest.TestCase):
    """Setup Test Case for pspolicy.homes4.base."""

    layer = PSPOLICY_HOMES4_BASE_INTEGRATION_TESTING

    def setUp(self):
        """Additional test setup."""
        self.app = self.layer['app']
        self.portal = self.layer['portal']

    def test_product_is_installed(self):
        """Validate that our product is installed."""
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('pspolicy.homes4.base'))

    def test_products_carousel_installed(self):
        """Test that Products.Carousel is installed."""
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('Carousel'))

    def test_products_doormat_installed(self):
        """Test that Products.Doormat is installed."""
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('Doormat'))

    def test_products_ploneformgen_installed(self):
        """Test that Products.PloneFormGen is installed."""
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('PloneFormGen'))

    def test_products_redirectiontool_installed(self):
        """Test that Products.RedirectionTool is installed."""
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('RedirectionTool'))

    def test_collective_carousel_installed(self):
        """Test that collective.carousel is installed."""
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('collective.carousel'))

    def test_collective_contentleadimage_installed(self):
        """Test that collective.contentleadimage is installed."""
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('collective.contentleadimage'))

    def test_collective_cover_installed(self):
        """Test that collective.cover is installed."""
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('collective.cover'))

    def test_collective_googleanalytics_installed(self):
        """Test that collective.googleanalytics is installed."""
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('collective.googleanalytics'))

    def test_collective_quickupload_installed(self):
        """Test that collective.quickupload is installed."""
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('collective.quickupload'))

    def test_plone_app_caching_installed(self):
        """Test that plone.app.caching is installed."""
        qi = self.portal.portal_quickinstaller
        if qi.isProductAvailable('plone.app.caching'):
            self.assertTrue(qi.isProductInstalled('plone.app.caching'))
        else:
            self.assertTrue(
                'plone.app.caching' in qi.listInstallableProfiles())

    def test_plone_app_theming_installed(self):
        """Test that plone.app.theming is installed."""
        qi = self.portal.portal_quickinstaller
        if qi.isProductAvailable('plone.app.theming'):
            self.assertTrue(qi.isProductInstalled('plone.app.theming'))
        else:
            self.assertTrue(
                'plone.app.theming' in qi.listInstallableProfiles())

    def test_plone_mls_listing_installed(self):
        """Test that plone.mls.listing is installed."""
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('plone.mls.listing'))

    def test_sc_social_like_installed(self):
        """Test that sc.social.like is installed."""
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('sc.social.like'))

    def test_theming_toolkit_core_installed(self):
        """Test that theming.toolkit.core is installed."""
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('theming.toolkit.core'))

    def test_theming_toolkit_viewlets_installed(self):
        """Test that theming.toolkit.viewlets is installed."""
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('theming.toolkit.viewlets'))

    def test_theming_toolkit_views_installed(self):
        """Test that theming.toolkit.views is installed."""
        import ipdb; ipdb.set_trace()
        qi = self.portal.portal_quickinstaller
        self.assertTrue(qi.isProductInstalled('theming.toolkit.views'))



# -*- coding: utf-8 -*-
"""Migration steps for pspolicy.homes4.base."""

# zope imports
from Products.CMFCore.utils import getToolByName
from Products.CMFPlone.interfaces.siteroot import IPloneSiteRoot
from zope.component import getUtility


PROFILE_ID = 'profile-pspolicy.homes4.base:default'


def migrate_to_1001(context):
    """Migrate from 1000 to 1001.

    * Update installed add-ons.
    """
    site = getUtility(IPloneSiteRoot)
    qi = getToolByName(site, 'portal_quickinstaller')
    qi.installProduct('theming.toolkit.views')
